==> websvn_2.0.orig.tar.gz: websvn-2.0/languages/spanish.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// spanish.php
//
// Spanish language strings

// The language name is displayed in the drop down box.  It MUST be encoded as Unicode (no HTML entities).
$lang["LANGUAGENAME"] = "Spanish";
$lang['LANGUAGETAG'] = 'es';

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "No se especificó un repositorio";
$lang["NOPATH"] = "Ruta no encontrada";
$lang["SUPPLYREP"] = "Por Favor, configure una ruta a un repositorio en include/config.php usando \$config->parentPath o \$config->addRepository<p>Verifique la guía de instalación para mas detalles";

$lang["DIFFREVS"] = "Diff entre versiones";
$lang["AND"] = "y";
$lang["REV"] = "Rev";
$lang["LINE"] = "Línea";
$lang["SHOWENTIREFILE"] = "Mostrar el archivo completo";
$lang["SHOWCOMPACT"] = "Solo mostrar áreas con diferencias";

$lang["DIFFPREV"] = "Comparar con el anterior";
$lang["BLAME"] = "Autoría";

$lang["REVINFO"] = "Información sobre la revisión";
$lang["GOYOUNGEST"] = "Ir a la última revisión";
$lang["LASTMOD"] = "Ultima modificación";
$lang["LOGMSG"] = "Mensaje de Log";
$lang["CHANGES"] = "Cambios";
$lang["SHOWCHANGED"] = "Mostrar archivos modificados";
$lang["HIDECHANGED"] = "Ocultar archivos modificados";
$lang["NEWFILES"] = "Archivos Nuevos";
$lang["CHANGEDFILES"] = "Archivos modificados";
$lang["DELETEDFILES"] = "Archivos borrados";
$lang["VIEWLOG"] = "Ver&nbsp;Log";
$lang["PATH"] = "Ruta";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Antigüedad";
$lang["LOG"] = "Log";
$lang["CURDIR"] = "Directorio Actual";
$lang["TARBALL"] = "Tarball";

$lang["PREV"] = "Ant";
$lang["NEXT"] = "Sig";
$lang["SHOWALL"] = "Mostrar todo";

$lang["BADCMD"] = "Error ejecutando ese comando";

$lang["POWERED"] = "Powered by <a href=\"http://websvn.tigris.org/\">WebSVN</a>";
$lang["PROJECTS"] = "Proyectos de&nbsp;Subversion";
$lang["SERVER"] = "Servidor de&nbsp;Subversion";

$lang["SEARCHLOG"] = "Buscar en el log";
$lang["CLEARLOG"] = "Limpiar la búsqueda actual";
$lang["MORERESULTS"] = "Buscar mas coincidencias";
$lang["NORESULTS"] = "Ningún log coincide con su búsqueda";
$lang["NOMORERESULTS"] = "No hay mas logs que coincidan con su búsqueda";
$lang['NOPREVREV'] = 'No hay revisión anterior';

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed"; 
$lang["FILESMODIFIED"] = "Archivo(s) modificados"; 
$lang["RSSFEED"] = "RSS feed"; 

$lang["LINENO"] = "Línea Nro.";
$lang["BLAMEFOR"] = "Información de culpa para rev";

$lang["YEARS"] = "Años";
$lang["MONTHS"] = "meses";
$lang["WEEKS"] = "semanas";
$lang["DAYS"] = "días";
$lang["HOURS"] = "horas";
$lang["MINUTES"] = "minutos";

$lang["GO"] = "Ir";

$lang["PATHCOMPARISON"] = "Comparación de rutas";
$lang["COMPAREPATHS"] = "Comparar Rutas";
$lang["COMPAREREVS"] = "Comparar Revisiones";
$lang["PROPCHANGES"] = "Cambios de propiedades :";
$lang["CONVFROM"] = "Esta Comparación muestra los cambios necesarios para convertir la ruta";
$lang["TO"] = "a";
$lang["REVCOMP"] = "Revertir comparación";
$lang["COMPPATH"] = "Comparar Ruta:";
$lang["WITHPATH"] = "Con Ruta:";
$lang["FILEDELETED"] = "Archivo Eliminado";
$lang["FILEADDED"] = "Archivo Nuevo";

// The following are defined by some languages to stop unwanted line splitting
// in the template files.

$lang["NOBR"] = "";
$lang["ENDNOBR"] = "";

// $lang["NOBR"] = "<nobr>";
// $lang["ENDNOBR"] = "</nobr>";

==> websvn_2.3.0.orig.tar.gz: websvn-2.3.0/languages/spanish.php <==
<?php

// WebSVN - Subversion repository viewing via the web using PHP
// Copyright (C) 2004 Tim Armes
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// --
//
// spanish.php
//
// Spanish language strings (UTF-8 encoding)

$lang["LANGUAGETAG"] = "es"; // Language tag (RFC 4646) for this translation.
$lang["LANGUAGENAMEENGLISH"] = "Spanish";
$lang["LANGUAGENAMENATIVE"] = "Español";
$lang["LANGUAGENAMEHTML"] = "Espa&ntilde;ol";

$lang["LOG"] = "Log";
$lang["DIFF"] = "Diff";

$lang["NOREP"] = "No se especificó un repositorio";
$lang["NOPATH"] = "Ruta no encontrada";
// $lang["NOACCESS"] = "You do not have the necessary permissions to read this content";
// $lang["RESTRICTED"] = "Restricted access";
$lang["SUPPLYREP"] = "Por favor, configure una ruta a un repositorio en include/config.php usando \$config->parentPath o \$config->addRepository<p>Verifique la guía de instalación para mas detalles";

$lang["DIFFREVS"] = "Diff entre versiones";
$lang["AND"] = "y";
$lang["REV"] = "Rev";
$lang["LINE"] = "Línea";
$lang["LINENO"] = "Línea Nro.";
$lang["SHOWENTIREFILE"] = "Mostrar el archivo completo";
$lang["SHOWCOMPACT"] = "Solo mostrar áreas con diferencias";
// $lang["IGNOREWHITESPACE"] = "Ignore whitespace";
// $lang["REGARDWHITESPACE"] = "Regard whitespace";

// $lang["LISTING"] = "Directory listing";
// $lang["FILEDETAIL"] = "Details";
$lang["DIFFPREV"] = "Comparar con el anterior";
$lang["BLAME"] = "Autoría";
$lang["BLAMEFOR"] = "Información de culpa para rev";

$lang["REVINFO"] = "Información sobre la revisión";
$lang["GOYOUNGEST"] = "Ir a la última revisión";
$lang["LASTMOD"] = "Ultima modificación";
$lang["LOGMSG"] = "Mensaje de Log";
$lang["CHANGES"] = "Cambios";
$lang["SHOWCHANGED"] = "Mostrar archivos modificados";
$lang["HIDECHANGED"] = "Ocultar archivos modificados";
$lang["NEWFILES"] = "Archivos Nuevos";
$lang["CHANGEDFILES"] = "Archivos modificados";
$lang["DELETEDFILES"] = "Archivos borrados";
$lang["VIEWLOG"] = "Ver Log";
$lang["PATH"] = "Ruta";
$lang["AUTHOR"] = "Autor";
$lang["AGE"] = "Antigüedad";
$lang["CURDIR"] = "Directorio Actual";
$lang["TARBALL"] = "Tarball";
$lang["DOWNLOAD"] = "Descargar";

$lang["PREV"] = "Ant";
$lang["NEXT"] = "Sig";
$lang["SHOWALL"] = "Mostrar todo";

$lang["BADCMD"] = "Error ejecutando ese comando";
// $lang["UNKNOWNREVISION"] = "Revision not found";

$lang["POWERED"] = "Powered by <a href=\"http://www.websvn.info/\">WebSVN</a>";
$lang["PROJECTS"] = "Proyectos de Subversion";
$lang["SERVER"] = "Servidor de Subversion";

// $lang["FILTER"] = "Filtering Options";
// $lang["STARTLOG"] = "From rev";
// $lang["ENDLOG"] = "To rev";
// $lang["MAXLOG"] = "Max revs";
$lang["SEARCHLOG"] = "Buscar en el log";
$lang["CLEARLOG"] = "Limpiar la búsqueda actual";
$lang["MORERESULTS"] = "Buscar mas coincidencias";
$lang["NORESULTS"] = "Ningún log coincide con su búsqueda";
$lang["NOMORERESULTS"] = "No hay mas logs que coincidan con su búsqueda";
$lang["NOPREVREV"] = "No hay revisión anterior";

$lang["RSSFEEDTITLE"] = "WebSVN RSS feed";
$lang["FILESMODIFIED"] = "Archivo(s) modificados";
$lang["RSSFEED"] = "RSS feed";

$lang["DAYLETTER"] = "d";
$lang["HOURLETTER"] = "h";
$lang["MINUTELETTER"] = "m";
$lang["SECONDLETTER"] = "s";

$lang["GO"] = "Ir";

$lang["PATHCOMPARISON"] = "Comparación de rutas";
$lang["COMPAREPATHS"] = "Comparar Rutas";
$lang["COMPAREREVS"] = "Comparar Revisiones";
$lang["PROPCHANGES"] = "Cambios de propiedades :";
$lang["CONVFROM"] = "Esta Comparación muestra los cambios necesarios para convertir la ruta";
$lang["TO"] = "a";
$lang["REVCOMP"] = "Revertir comparación";
$lang["COMPPATH"] = "Comparar Ruta:";
$lang["WITHPATH"] = "Con Ruta:";
$lang["FILEDELETED"] = "Archivo Eliminado";
$lang["FILEADDED"] = "Archivo Nuevo";

// The following are defined by some languages to stop unwanted line splitting
// in the template files.

$lang["NOBR"] = "";
$lang["ENDNOBR"] = "";
